@@ -7,8 +7,9 @@ kProjectConfigNameYaml = 'project_config.yaml'
 
 kiDDSConfigName = 'idds_config.json'
 kiDDSSearchSpaceName = 'search_space.json'
-kiDDSHPinput = 'input_hyperparameters.json'
+kiDDSHPinput = 'input.json'
 kiDDSHPoutput = 'output.json'
+kiDDSMetrics = "metrics.tgz"
 
 kConfigAction = ['create', 'recreate', 'update']
 
@@ -41,7 +42,7 @@ kGridSiteWorkDir = '/srv/workDir/'
 try:
     from hpogrid.utils.grid_site_info import GridSiteInfo
     kGPUGridSiteList = GridSiteInfo.list_sites()
-    kGPUGridSiteList += ['ANALY_CERN-PTEST','ANY']
+    kGPUGridSiteList += ['ANALY_CERN-PTEST','ANY', 'UKI-NORTHGRID-MAN-HEP']
 except:
     kGPUGridSiteList = None
 
