@@ -36,10 +36,10 @@ class HPOReport():
         self.attrib['mode'] = data['mode']
         if self.verbose:
             print('INFO: Setting up HPO report with the following attributes')
-            print('Projet Name     : {project_name} \n'
-                  'Hyperparameters : {hyperparameters}\n'
-                  'Metric          : {metric}\n'
-                  'Mode            : {mode}'.format(**self.attrib))
+            print('Project Name     : {project_name} \n'
+                  'Hyperparameters  : {hyperparameters}\n'
+                  'Metric           : {metric}\n'
+                  'Mode             : {mode}'.format(**self.attrib))
 
     def check_consistency(self, data):
         if not validate_job_metadata(data):
@@ -303,10 +303,11 @@ class HPOTaskHandle(HPOReport):
         return filtered_datasets
 
     def extract_metadata(self, dataset):
+        #set_trace()
         if 'jobs_metadata' in dataset:
             keys = list(dataset['jobs_metadata'].keys())
             if keys:
-                return dataset['jobs_metadata'][keys[0]]
+                return dataset['jobs_metadata'][keys[0]]['user_job_metadata']
             else:
                 return None
         else:
