@@ -5,14 +5,20 @@ import fnmatch
 
 from hpogrid.utils import stylus
 from hpogrid.components.defaults import *
+from hpogrid.utils.helper import load_configuration, get_base_path, get_config_dir
 
 kActionList = ['create', 'recreate', 'update', 'list', 'show', 'remove']  
-kConfigAction = ['create', 'recreate', 'update']
 
 class ConfigurationBase():
+    
+    config_type = 'SUPPRESS'
+    description = 'Manage configuration'
+    usage = 'hpogrid <config_type> <action> <config_name> [<options>]'
+    list_columns = []
+    show_columns = []
+    json_interpreted = []
 
     def __init__(self):
-        self.initialize()
         parser = self.get_parser() 
         args = parser.parse_args(sys.argv[2:3])
         action = args.action
@@ -28,13 +34,6 @@ class ConfigurationBase():
             parser.print_help()
             exit(1)            
 
-    def initialize(self):
-        self.description = 'Manage configuration'
-        self.usage = 'hpogrid <config_type> <action> <config_name> [<options>]'
-        self.config_type = 'SUPPRESS'
-        self.list_columns = []
-        self.show_columns = []
-
     def get_base_parser(self):
         parser = argparse.ArgumentParser(
             description=self.description,
@@ -56,38 +55,6 @@ class ConfigurationBase():
             raise ValueError('Unknown method: {}'.format(action))
         return parser
 
-    def get_base_dir(self, config_type=None, force_create=True):
-
-        if config_type is None:
-            config_type = self.config_type
-            
-        if config_type == 'project':
-            base_dir = os.path.join(os.environ[kHPOGridEnvPath], 'projects')
-        else:
-            base_dir = os.path.join(os.environ[kHPOGridEnvPath], 'config', config_type)
-
-        if (not os.path.exists(base_dir)) and force_create:
-            os.makedirs(base_dir, exist_ok=True)
-        return base_dir
-
-    def get_config_path(self, config_name=None, config_type=None, extension='.json'):
-        if config_name is None:
-            config_name = self.config_name
-        if config_type is None:
-            config_type = self.config_type
-        base_dir = self.get_base_dir(config_type)
-        config_base_name = '{}{}'.format(config_name, extension)
-        config_path = os.path.join(base_dir, config_base_name)
-        return config_path
-
-    def remove(self, name):
-        config_path = self.get_config_path(name)
-        if os.path.exists(config_path):
-            os.remove(config_path)
-            print('INFO: Removed file {}'.format(config_path))
-        else:
-            print('ERROR: Cannot remove file {}. File does not exist.'.format(config_path))
-
     def get_updated_config(self, config):
         non_updated_keys = []
         for key in config:
@@ -128,7 +95,13 @@ class ConfigurationBase():
     def process_config(self, config):
         for key in config:
             if isinstance(config[key], bool):
-                config[key] = int(config[key])
+                config[key] = int(config[key])            
+            if (key in self.json_interpreted) and isinstance(config[key], str):
+                try:
+                    config[key] = json.loads(config[key])
+                except JSONDecodeError:
+                    raise ValueError('ERROR: Cannot decode the value of {} into json format.'
+                        'Please check your input.'.format(key))   
         return config
 
     def save(self, config, name, action='create'):
@@ -145,29 +118,103 @@ class ConfigurationBase():
             print('INFO: {} {} configuration {}'.format(action_map[action], self.config_type, config_path))
             self.show(name)
 
-    def get_config_list(self, expr=None):
-        if not expr:
-            expr = '*'
-        base_dir = self.get_base_dir()
-        config_list = [os.path.splitext(d)[0] for d in os.listdir(base_dir) if not d.startswith('.')]
+    @classmethod
+    def get_config_dir(cls, force_create:bool=True):
+        """Returns the directory under which the specific type of configuration files
+        are stored
+        
+        Args:
+            force_create: boolean, default=True
+                Whether to force create the directory if not already exists
+        """
+        config_dir = get_config_dir(cls.config_type)
+
+        if (not os.path.exists(config_dir)) and force_create:
+            os.makedirs(config_dir, exist_ok=True)
+        return config_dir
+    
+    @classmethod
+    def get_config_path(cls, config_name:str=None, extension='.json'):
+        """Returns the full path of a configuration file
+        
+        Args:
+            config_name: str
+                Name of the configuration file
+            extension: str
+                File extension for configuration file
+        """
+
+        config_dir = cls.get_config_dir()
+        config_base_name = '{}{}'.format(config_name, extension)
+        config_path = os.path.join(config_dir, config_base_name)
+        return config_path
+    
+    @classmethod
+    def get_config_list(cls, expr:str=None):
+        """Returns a list of configuration files for a specific type of configuration
+        
+        Args:
+            expr: str
+                Regular expression for filtering name of configuration files
+        """
+        expr = expr if expr is not None else '*'
+        
+        config_dir = cls.get_config_dir()
+        config_list = [os.path.splitext(d)[0] for d in os.listdir(config_dir) if not d.startswith('.')]
         if expr is not None:
             config_list = fnmatch.filter(config_list, expr)
         return config_list
-
-    def load_config(self, config_name):
-        config_path = self.get_config_path(config_name)
-        if not (os.path.exists(config_path)):
-            raise FileNotFoundError("The configuration file {} does not exist.".format(config_path))
-        config = json.load(open(config_path))
+    
+    @classmethod
+    def load(cls, name:str):
+        """Returns a specified configuration file
+        
+        Args:
+            name: str
+                Name of configuration file
+        """
+        config_path = cls.get_config_path(name)
+        config = load_configuration(config_path)
         return config
 
-    def list(self, expr=None):
-        config_list = self.get_config_list(expr)
-        table = stylus.create_table(config_list, self.list_columns)
+    @classmethod
+    def list(cls, expr:str=None):
+        """List out configuration files for a specific type of configuration as a table
+        
+        Args:
+            expr: str
+                Regular expression for filtering name of configuration files        
+            exclude: list[str]
+                Configuration files to exclude from listing
+        """
+        config_list = cls.get_config_list(expr)
+        table = stylus.create_table(config_list, cls.list_columns)
         print(table)
-
-    def show(self, name):
-        config = self.load_config(name)
+    
+    @classmethod
+    def show(cls, name:str):
+        """Display the content of a configuration file
+        
+        Args:
+            name: str
+                Name of configuration file        
+        """
+        config = cls.load(name)
         #table = stylus.create_table(config.items(), self.show_columns, indexed=False)
-        table = stylus.create_formated_dict(config, self.show_columns, indexed=False)
+        table = stylus.create_formated_dict(config, cls.show_columns, indexed=False)
         print(table)  
+        
+    @classmethod
+    def remove(cls, name):
+        """Removes a configuration file
+        
+        Args:
+            name: str
+                Name of the configuration file to remove
+        """
+        config_path = cls.get_config_path(name)
+        if os.path.exists(config_path):
+            os.remove(config_path)
+            print('INFO: Removed file {}'.format(config_path))
+        else:
+            print('ERROR: Cannot remove file {}. File does not exist.'.format(config_path))
\ No newline at end of file
