@@ -11,20 +11,22 @@ from pdb import set_trace
 
 from hpogrid.utils import stylus, helper
 from hpogrid.components.defaults import *
-from hpogrid.configuration.configuration_base import ConfigurationBase, kConfigAction
+from hpogrid import ConfigurationBase
 
 kConfigList = ['scripts_path', 'model_config', 'search_space', 'hpo_config', 'grid_config']
 
 class ProjectConfiguration(ConfigurationBase):
+    
+    config_type = 'project'
+    description = 'Manage a project for hyperparamter optimization'
+    usage = 'hpogrid project <action> <project_name> [<options>]'
+    list_columns = ['Project Title']
+    show_columns = ['Attribute', 'Value']  
+    json_interpreted = []
 
-    def initialize(self):
-        self.description = 'Manage a project for hyperparamter optimization'
-        self.usage = 'hpogrid project <action> <project_name> [<options>]'
-        self.config_type = 'project'
-        self.list_columns = ['Project Title']
-        self.show_columns = ['Attribute', 'Value']  
+    def __init__(self):
         self.project_config = {}
-
+        super().__init__()
 
     def get_parser(self, action=None):
         parser = self.get_base_parser()           
@@ -66,37 +68,52 @@ class ProjectConfiguration(ConfigurationBase):
             'hpo_config': 'hpo',
             'grid_config': 'grid',
             'model_config': 'model',
-            'search_space': 'search space'
+            'search_space': 'search_space'
         }
 
         # check if input configuration files exist
-        for key in config_type_map:
-            if (key in config) and (config[key] is not None):
-                config_type = config_type_map[key].replace(' ','_')
-                config_path = self.get_config_path(config[key], config_type)
+        for config_type in config_type_map:
+            if (config_type in config) and (config[config_type] is not None):
+                config_dir = helper.get_config_dir(config_type_map[config_type])
+                config_base_name = '{}.json'.format(config[config_type])
+                config_path = os.path.join(config_dir, config_base_name)
+                config_name = config_type_map[config_type].replace('_',' ')
                 if not os.path.exists(config_path):
-                    raise FileNotFoundError('ERROR: Path to {} configuration {} does not exist.'.format(config_type, config_path))
+                    raise FileNotFoundError('Path to {} configuration {}'
+                                            ' does not exist.'.format(config_name, config_path))
                 with open(config_path,'r') as config_file:
-                    config[key] = json.load(config_file)
-                print('INFO: Loaded {} configuration from {} '.format(config_type_map[key], config_path))
+                    config[config_type] = json.load(config_file)
+                print('INFO: Loaded {} configuration from {} '.format(config_name, config_path))
             else:
-                print('INFO: Path to {} configuration is not specified. Skipping...'.format(config_type_map[key]))
+                print('INFO: Path to {} configuration is not specified. Skipping...'.format(config_name))
 
         return config
+    
 
-    def get_project_path(self, proj_name):
-        return self.get_config_path(proj_name, self.config_type, extension='')
 
-    def save(self, config, name, action='create'):
-        proj_name = name
-        proj_path = self.get_project_path(proj_name)
+    @classmethod
+    def save(cls, config, name=None, action='create'):
+        if action not in kConfigAction:
+            raise ValueError('Unknown action "{}"'.format(action))
+        proj_name = config.get('project_name', name)
+        if not proj_name:
+            raise ValueError('Project name not specified in configuration')
+        proj_path = cls.get_project_path(proj_name)
+        
+        action_map = {
+            'create': 'Creating',
+            'recreate': 'Recreating',
+            'update': 'Updating'
+        }
+        
+        print('INFO: {} project "{}"'.format(action_map.get(action, action), proj_name))
         if (os.path.exists(proj_path)):
             if  action == 'create':
-                print('ERROR: Project titled {} already exists. If you want to overwrite,'
+                print('ERROR: Project "{}" already exists. If you want to overwrite,'
                     ' use "recreate" or "update" action instead of "create".'.format(proj_name))
                 return None
             elif action == 'recreate':
-                backup_dir = self.get_config_path('backup', self.config_type, extension='')
+                backup_dir = cls.get_project_path('backup')
                 os.makedirs(backup_dir, exist_ok=True)
                 timestamp = datetime.now().strftime("%Y%m%d%H%M%S")
                 backup_proj_name = os.path.join(backup_dir, '{}_{}'.format(proj_name, timestamp))
@@ -112,12 +129,12 @@ class ProjectConfiguration(ConfigurationBase):
 
         # copy training scripts to the project directory
         if ('scripts_path' in config) and (config['scripts_path'] is not None):
+            print('INFO: Copying traning scripts from {} to {}'.format(config['scripts_path'], scripts_dir))
             # copy contents of directory to project/scrsipts/
             if os.path.isdir(config['scripts_path']):
-                dir_util.copy_tree(config['scripts_path'], scripts_dir)
+                helper.copytree(config['scripts_path'], scripts_dir)
             else:
                 shutil.copy2(config['scripts_path'], scripts_dir)
-            print('INFO: From {} copied training scripts to {}'.format(config['scripts_path'], scripts_dir))
 
         
         project_config = {}
@@ -140,28 +157,63 @@ class ProjectConfiguration(ConfigurationBase):
             yaml.dump(project_config, proj_config_file, default_flow_style=False, sort_keys=False)
             print('INFO: Created project configuration: {}'.format(project_config_path_yaml))
             
-        search_space = project_config['search_space']    
-        idds_search_space_path = os.path.join(config_dir, kiDDSSearchSpaceName)
-        with open(idds_search_space_path, 'w') as idds_search_space_file:
-            json.dump(search_space, idds_search_space_file)
-            print('INFO: Created iDDS search space file: {}'.format(idds_search_space_path))
-            
-    def get_config_list(self, expr=None):
-        project_list = [ s for s in super().get_config_list() if s is not 'backup']
-        return project_list
-
-    def remove(self, name):
-        proj_path = self.get_project_path(name)
-        if os.path.exists(proj_path):
+        action_map = {
+            'create': 'created',
+            'recreate': 'recreated',
+            'update': 'updated'
+        }
+        print('INFO: Successfully {} project "{}"'.format(action_map.get(action, action), proj_name))
+        
+    @classmethod
+    def remove(cls, name):
+        project_path = cls.get_project_path(name)
+        if os.path.exists(project_path):
             print('WARNING: To avoid accidental deletion of important files. '
-                'Please delete your project manually at:\n{}'.format(proj_path))
+                'Please delete your project manually at:\n{}'.format(project_path))
         else:
-            print('ERROR: Cannot remove project in {}. Path does not exist.'.format(proj_path))
+            print('ERROR: Cannot remove project in {}. Path does not exist.'.format(project_path))
+            
+    @classmethod
+    def get_project_path(cls, name):
+        """Returns the path to the project
+        
+        Args:
+            name: str
+                Name of project
+        """
+        return helper.get_project_path(name)
+    
+    @classmethod
+    def get_config_path(cls, config_name:str=None):
+        """Returns the full path of a project configuration file
+        
+        Args:
+            config_name: str
+                Name of the project
+        """
+        return helper.get_project_config_path(proj_name=config_name)         
 
-    def show(self, name):
-        proj_path = self.get_project_path(name)
-        if os.path.exists(proj_path):
-            config = helper.get_project_config(name)
-            print(yaml.dump(config, allow_unicode=True, default_flow_style=False, sort_keys=False))
-        else:
-            print('ERROR: Project {} does not exist.'.format(name))
\ No newline at end of file
+    @classmethod
+    def list(cls, expr:str=None):
+        """List out configuration files for a specific type of configuration as a table
+        
+        Args:
+            expr: str
+                Regular expression for filtering name of configuration files        
+            exclude: list[str]
+                Configuration files to exclude from listing
+        """
+        project_list = helper.get_project_list(expr)
+        table = stylus.create_table(project_list, cls.list_columns)
+        print(table)
+        
+    @classmethod
+    def show(cls, name:str):
+        """Display the content of a configuration file
+        
+        Args:
+            name: str
+                Name of configuration file        
+        """
+        config = cls.load(name)
+        print(yaml.dump(config, allow_unicode=True, default_flow_style=False, sort_keys=False))   
\ No newline at end of file
