@@ -24,8 +24,8 @@ def transpose_config(config):
     generator_options = {}
     generator_options['n_point'] = '%NUM_POINTS'
     generator_options['max_point'] = '%MAX_POINTS'
-    generator_options['infile'] = os.path.join("/HPOiDDS", '%IN')
-    generator_options['outfile'] = os.path.join("/HPOiDDS", '%OUT')
+    generator_options['infile'] = os.path.join(kiDDSBasePath, '%IN')
+    generator_options['outfile'] = os.path.join(kiDDSBasePath, '%OUT')
     generator_options['lib'] = library
     if (library == 'nevergrad') and method:
         generator_options['method'] = method
@@ -33,10 +33,10 @@ def transpose_config(config):
 
     # format idds configuration
     idds_config = {}
-    #idds_config['steeringExec'] = ("run --rm -v \"$(pwd)\":{idds_base_path} {container} " +\
-    #"/bin/bash -c \"{cmd}\" ").format(idds_base_path=kiDDSBasePath, container=kDefaultiDDSContainer, cmd=generator_cmd)
     idds_config['steeringExec'] = ("run --rm -v \"$(pwd)\":{idds_base_path} {container} " +\
-    "/bin/bash -c \"{cmd}\" ").format(idds_base_path="/HPOiDDS", container="gitlab-registry.cern.ch/zhangruihpc/steeringcontainer:0.0.2", cmd=generator_cmd)
+    "/bin/bash -c \"{cmd}\" ").format(idds_base_path=kiDDSBasePath, container=kDefaultiDDSContainer, cmd=generator_cmd)
+    #idds_config['steeringExec'] = ("run --rm -v \"$(pwd)\":{idds_base_path} {container} " +\
+    #"/bin/bash -c \"{cmd}\" ").format(idds_base_path="/HPOiDDS", container="gitlab-registry.cern.ch/zhangruihpc/steeringcontainer:0.0.2", cmd=generator_cmd)
 
     idds_config['evaluationExec'] = "pip install --upgrade hpogrid && " + \
                                     "hpogrid run {project_name} --mode idds".format(project_name=project_name)
@@ -65,9 +65,9 @@ def create_idds_output_from_metadata(metadata):
     idds_output = {}
     idds_output['status'] = 0
     loss = []
-    metric = summary['metric']
-    for result in summary['result']:
-        loss.append(result[sumetric])
+    metric = metadata['metric']
+    for index in metadata['result']:
+        loss.append(metadata['result'][index][metric])
     if len(loss) == 1:
         loss = loss[0]
     idds_output['loss'] = loss
